/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.acct;

import java.util.Date;

import dk.vajhoej.record.FieldType;
import dk.vajhoej.record.Struct;
import dk.vajhoej.record.StructField;

/**
 * Class AcctPackResource represents an accounting packet with resource usage information.
 */
@Struct
public class AcctPackResource extends AcctPack {
	@StructField(n=2,type=FieldType.VMSTIME)
	private Date login;
	@StructField(n=3,type=FieldType.INT4)
	private int status;
	@StructField(n=4,type=FieldType.INT4)
	private int imgcnt;
	@StructField(n=5,type=FieldType.INT4)
	private int cputime;
	@StructField(n=6,type=FieldType.INT4)
	private int faults;
	@StructField(n=7,type=FieldType.INT4)
	private int faultio;
	@StructField(n=8,type=FieldType.INT4)
	private int wspeak;
	@StructField(n=9,type=FieldType.INT4)
	private int pagefl;
	@StructField(n=10,type=FieldType.INT4)
	private int diocnt;
	@StructField(n=11,type=FieldType.INT4)
	private int biocnt;
	@StructField(n=12,type=FieldType.INT4)
	private int volumes;
	@StructField(n=13,type=FieldType.INT4)
	private int vp_cputime;
	/**
	 * Get login time.
	 * @return login time
	 */
	public Date getLogin() {
		return login;
	}
	/**
	 * Get status.
	 * @return status
	 */
	public int getStatus() {
		return status;
	}
	/**
	 * Get image count.
	 * @return image count
	 */
	public int getImgcnt() {
		return imgcnt;
	}
	/**
	 * Get CPU time.
	 * @return cpu time
	 */
	public int getCputime() {
		return cputime;
	}
	/**
	 * Get page faults.
	 * @return page faults
	 */
	public int getFaults() {
		return faults;
	}
	/**
	 * Get page fault IO's.
	 * @return page fault IO's
	 */
	public int getFaultio() {
		return faultio;
	}
	/**
	 * Get working set peak
	 * @return working set peak
	 */
	public int getWspeak() {
		return wspeak;
	}
	/**
	 * Get max page file usage.
	 * @return max page file usage
	 */
	public int getPagefl() {
		return pagefl;
	}
	/**
	 * Get direct IO count.
	 * @return direct IO count
	 */
	public int getDiocnt() {
		return diocnt;
	}
	/**
	 * Get buffered IO count.
	 * @return buffered IO count
	 */
	public int getBiocnt() {
		return biocnt;
	}
	/**
	 * Get number volumes mounted.
	 * @return number volumes mounted
	 */
	public int getVolumes() {
		return volumes;
	}
	/**
	 * Get vector CPU time.
	 * @return vector CPU time
	 */
	public int getVp_cputime() {
		return vp_cputime;
	}
	protected String subToString() {
		return "cpu=" + cputime + ",mem=" + wspeak + ",io=" + (diocnt + biocnt);
	}
}
