/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.acct;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;

import dk.vajhoej.record.ArrayField;
import dk.vajhoej.record.FieldType;
import dk.vajhoej.record.Struct;
import dk.vajhoej.record.StructField;

/**
 * Class AcctRec represents an accounting record.
 */
@Struct
public class AcctRec {
	private static final DateFormat vmsdf = new SimpleDateFormat("dd-MMM-yyyy HH:mm:ss");
	@StructField(n=0,type=FieldType.STRUCT)
	private AcctRecType type;
	@StructField(n=1,type=FieldType.INT2)
	private short length;
	@StructField(n=2,type=FieldType.VMSTIME)
	private Date systime;
	@ArrayField(elements=0)
	@StructField(n=3,type=FieldType.STRUCT)
	private AcctPack[] packs;
	@StructField(n=4,type=FieldType.FIXSTR,length=0)
	private String eol;
	/**
	 * Construct instance.
	 */
	public AcctRec() {
		packs = new AcctPack[0];
	}
	/**
	 * Get accounting record type.
	 * @return accounting record type
	 */
	public AcctRecType getType() {
		return type;
	}
	/**
	 * Get accounting record length.
	 * @return accounting record length
	 */
	public short getLength() {
		return length;
	}
	/**
	 * Get time.
	 * @return VMS time
	 */
	public Date getSystime() {
		return systime;
	}
	/**
	 * Get accounting packets.
	 * @return accounting packets
	 */
	public AcctPack[] getPacks() {
		return packs;
	}
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("(type=" + type + ",length=" + length);
		for(AcctPack p : packs) {
			sb.append(",pack=" + p);
		}
		sb.append(",systime=" + vmsdf.format(systime));
		sb.append(")");
		return sb.toString();
	}
}

